ValkyrieElementType

Enum ValkyrieElementType 

pub enum ValkyrieElementType {
Show 76 variants Root, Eof, Whitespace, Newline, LineComment, BlockComment, Error, Attribute, NamePath, Type, Namespace, Class, Structure, ParameterList, BlockExpression, IdentifierExpression, PathExpression, Statement, LetStatement, ExprStatement, Expression, CallExpression, Param, ReturnExpression, LiteralExpression, BooleanLiteral, BinaryExpression, UnaryExpression, ParenthesizedExpression, IndexExpression, OffsetExpression, FieldExpression, IfExpression, MatchExpression, LoopExpression, BreakExpression, ContinueExpression, YieldExpression, RaiseExpression, CatchExpression, ResumeExpression, WithExpression, ApplyBlock, ObjectExpression, LambdaExpression, Micro, Mezzo, Macro, Struct, Enum, Enums, Trait, AssociatedType, Impl, Field, Method, Variant, Property, Flags, Widget, Singleton, EffectDefinition, UsingStatement, TemplateText, TemplateControl, Interpolation, TemplateComment, Pattern, ArgList, GenericParameterList, GenericArgumentList, MatchArm, Parameter, AnonymousClass, GenericParameter, SuperCallExpression,
}
Element types for Valkyrie language syntax tree nodes.

Variants



Root

Root node of the syntax tree.



Eof

End of file marker.



Whitespace

Whitespace token.



Newline

Newline token.



LineComment

Line comment token.



BlockComment

Block comment token.



Error

Error node.



Attribute

Attribute node.



NamePath

Name path node.



Type

Type node.



Namespace

Namespace node.



Class

Class node.



Structure

Structure node (value type).



ParameterList

Parameter list node.



BlockExpression

Block expression node.



IdentifierExpression

Identifier expression node.



PathExpression

Path expression node.



Statement

Statement node.



LetStatement

Let statement node.



ExprStatement

Expression statement node.



Expression

Expression node.



CallExpression

Call expression node.



Param

Parameter node.



ReturnExpression

Return expression node.



LiteralExpression

Literal expression node.



BooleanLiteral

Boolean literal node.



BinaryExpression

Binary expression node.



UnaryExpression

Unary expression node.



ParenthesizedExpression

Parenthesized expression node.



IndexExpression

Index expression node.



OffsetExpression

Offset expression node (cardinal indexing, 0-based).



FieldExpression

Field expression node.



IfExpression

If expression node.



MatchExpression

Match expression node.



LoopExpression

Loop expression node.



BreakExpression

Break expression node.



ContinueExpression

Continue expression node.



YieldExpression

Yield expression node.



RaiseExpression

Raise expression node.



CatchExpression

Catch expression node.



ResumeExpression

Resume expression node.



WithExpression

With expression node (functional record update).



ApplyBlock

Apply block node.



ObjectExpression

Object expression node.



LambdaExpression

Lambda expression node.



Micro

Micro definition node.



Mezzo

Mezzo definition node.



Macro

Macro definition node.



Struct

Struct definition node.



Enum

Enum definition node.



Enums

Enums definition node.



Trait

Trait definition node.



AssociatedType

Associated type node.



Impl

Impl definition node.



Field

Field definition node.



Method

Method definition node.



Variant

Variant definition node.



Property

Property definition node (getter/setter).



Flags

Flags definition node.



Widget

Widget definition node.



Singleton

Singleton definition node.



EffectDefinition

Effect definition node.



UsingStatement

Using statement node.



TemplateText

Template text node.



TemplateControl

Template control node.



Interpolation

Interpolation node.



TemplateComment

Template comment node.



Pattern

Pattern node.



ArgList

Argument list node.



GenericParameterList

Generic parameter list node.



GenericArgumentList

Generic argument list node.



MatchArm

Match arm node.



Parameter

Parameter node.



AnonymousClass

Anonymous class node.



GenericParameter

Generic parameter node.



SuperCallExpression

Super call expression node.